from .holidays import Country


class BR(Country):
    id = "BR"
    languages = ["pt"]
    default_lang = "pt"
    regions = ["AC", "AL", "AP", "AM", "BA", "CE", "DF", "ES", "GO", "MA", "MT", "MS", "MG", "PA", "PB", "PR", "PE",
               "PI", "RJ", "RN", "RS", "RO", "RR", "SC", "SP", "SE", "TO"]
